==> kubernetes-model-1.0.60-sources.jar: io/fabric8/openshift/api/model/ClusterRoleBindingListFluent.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import javax.validation.constraints.NotNull;
import java.util.List;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.sundr.builder.annotations.Buildable;
import javax.annotation.Generated;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import lombok.EqualsAndHashCode;
import com.fasterxml.jackson.databind.annotation.JsonDeserialize;
import io.fabric8.kubernetes.api.model.ListMeta;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;
import javax.validation.Valid;
import java.lang.Object;
import lombok.ToString;
import java.util.Map;

public interface ClusterRoleBindingListFluent<A extends ClusterRoleBindingListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(ClusterRoleBinding... items);
    public A removeFromItems(ClusterRoleBinding... items);
    public List<ClusterRoleBinding> getItems();
    public A withItems(List<ClusterRoleBinding> items);
    public A withItems(ClusterRoleBinding... items);
    public ClusterRoleBindingListFluent.ItemsNested<A> addNewItem();
    public ClusterRoleBindingListFluent.ItemsNested<A> addNewItemLike(ClusterRoleBinding item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public ClusterRoleBindingListFluent.MetadataNested<A> withNewMetadata();
    public ClusterRoleBindingListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ClusterRoleBindingListFluent.MetadataNested<A> editMetadata();
    public ClusterRoleBindingListFluent.MetadataNested<A> editOrNewMetadata();
    public ClusterRoleBindingListFluent.MetadataNested<A> editOrNewMetadataLike(ListMeta item);
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ClusterRoleBindingFluent<ClusterRoleBindingListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ListMetaFluent<ClusterRoleBindingListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> kubernetes-model-1.0.61-sources.jar: io/fabric8/openshift/api/model/ClusterRoleBindingListFluent.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.String;
import javax.validation.constraints.NotNull;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.util.List;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ListMeta;
import java.lang.Object;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonIgnore;
import io.fabric8.kubernetes.api.builder.Nested;
import io.fabric8.kubernetes.api.model.ListMetaFluent;
import io.fabric8.kubernetes.api.model.ListMetaBuilder;

public interface ClusterRoleBindingListFluent<A extends ClusterRoleBindingListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public A addToItems(ClusterRoleBinding... items);
    public A removeFromItems(ClusterRoleBinding... items);
    public List<ClusterRoleBinding> getItems();
    public A withItems(List<ClusterRoleBinding> items);
    public A withItems(ClusterRoleBinding... items);
    public ClusterRoleBindingListFluent.ItemsNested<A> addNewItem();
    public ClusterRoleBindingListFluent.ItemsNested<A> addNewItemLike(ClusterRoleBinding item);
    public String getKind();
    public A withKind(String kind);
    public ListMeta getMetadata();
    public A withMetadata(ListMeta metadata);
    public ClusterRoleBindingListFluent.MetadataNested<A> withNewMetadata();
    public ClusterRoleBindingListFluent.MetadataNested<A> withNewMetadataLike(ListMeta item);
    public ClusterRoleBindingListFluent.MetadataNested<A> editMetadata();
    public A withNewMetadata(String resourceVersion,String selfLink);

    public interface ItemsNested<N> extends Nested<N>,ClusterRoleBindingFluent<ClusterRoleBindingListFluent.ItemsNested<N>>{

        
    public N endItem();    public N and();
}
    public interface MetadataNested<N> extends Nested<N>,ListMetaFluent<ClusterRoleBindingListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
